@@ -58,7 +58,7 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
         "url": "https://json.schemastore.org/github-workflow",
         "hook_config": {
             "name": "Validate GitHub Workflows",
-            "files": r"^\.github/workflows/",
+            "files": r"^\.github/workflows/[^/]+$",
             "types": "yaml",
         },
     },
@@ -67,6 +67,7 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
         "/editor/schema/ci.json",
         "hook_config": {
             "name": "Validate GitLab CI config",
+            "add_args": ["--data-transform", "gitlab-ci"],
             "files": r"^.*\.gitlab-ci.yml$",
             "types": "yaml",
         },
